==> j2objc-3.0.0.tar.gz: j2objc-3.0.0/jre_emul/android/platform/libcore/ojluni/src/main/java/java/net/NetUtil.java <==
/*
 * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package java.net;

class NetUtil {

    // Value of jdk.net.revealLocalAddress
    private static boolean revealLocalAddress;

    // True if jdk.net.revealLocalAddress had been read
    private static volatile boolean propRevealLocalAddr;

    /*
     * Returns true if security check on localAddress is disabled
     */
    static boolean doRevealLocalAddress() {
        return propRevealLocalAddr ? revealLocalAddress
                                     : readRevealLocalAddr();

    }

    private static boolean readRevealLocalAddr() {
        SecurityManager sm = System.getSecurityManager();
        if (sm != null) {
            try {
                /*
                revealLocalAddress = Boolean.parseBoolean(
                      AccessController.doPrivileged(
                          new PrivilegedExceptionAction<String>() {
                              @Override
                              public String run() {
                                  return System.getProperty(
                                      "jdk.net.revealLocalAddress");
                              }
                          }));
                 */
                 revealLocalAddress = Boolean.parseBoolean(
                     System.getProperty("jdk.net.revealLocalAddress"));

            } catch (Exception e) {
                //revealLocalAddress is false
            }
            propRevealLocalAddr = true;
        }
        /*
         * No security manager, or security check passed or
         * jdk.net.revealLocalAddress set to true
         */
        return revealLocalAddress;
    }

}

==> j2objc-3.1.tar.gz: j2objc-3.1/jre_emul/android/platform/libcore/ojluni/src/main/java/java/net/NetUtil.java <==
/*
 * Copyright (c) 2013, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package java.net;

class NetUtil {

    // Value of jdk.net.revealLocalAddress
    private static boolean revealLocalAddress;

    // True if jdk.net.revealLocalAddress had been read
    private static volatile boolean propRevealLocalAddr;

    /*
     * Returns true if security check on localAddress is disabled
     */
    static boolean doRevealLocalAddress() {
        return propRevealLocalAddr ? revealLocalAddress
                                     : readRevealLocalAddr();

    }

    private static boolean readRevealLocalAddr() {
        // SecurityManager sm = System.getSecurityManager();
        // if (sm != null) {
        //     try {
        //         /*
        //         revealLocalAddress = Boolean.parseBoolean(
        //               AccessController.doPrivileged(
        //                   new PrivilegedExceptionAction<String>() {
        //                       @Override
        //                       public String run() {
        //                           return System.getProperty(
        //                               "jdk.net.revealLocalAddress");
        //                       }
        //                   }));
        //          */
        //          revealLocalAddress = Boolean.parseBoolean(
        //              System.getProperty("jdk.net.revealLocalAddress"));

        //     } catch (Exception e) {
        //         //revealLocalAddress is false
        //     }
        //     propRevealLocalAddr = true;
        // }
        /*
         * No security manager, or security check passed or
         * jdk.net.revealLocalAddress set to true
         */
        return revealLocalAddress;
    }

}
